@@ -1,6 +1,6 @@
 from pathlib import Path
 from unittest import mock
-import responses # type: ignore
+import responses  # type: ignore
 import json
 import gzip
 from tests.cli_test_case import CliTestCase
@@ -19,7 +19,7 @@ class CypressTest(CliTestCase):
         self.assertEqual(result.exit_code, 0)
 
         payload = json.loads(gzip.decompress(
-            b''.join(responses.calls[0].request.body)).decode())
+            b''.join(responses.calls[1].request.body)).decode())
         expected = self.load_json_from_file(
             self.test_files_dir.joinpath('record_test_result.json'))
 
@@ -39,11 +39,11 @@ class CypressTest(CliTestCase):
             self.test_files_dir.joinpath('subset_result.json'))
         self.assert_json_orderless_equal(expected, payload)
 
-
     @responses.activate
     def test_empty_xml(self):
         # parse empty test report XML
         result = self.cli('record', 'tests',  '--session', self.session,
                           'cypress', str(self.test_files_dir) + "/empty.xml")
         self.assertEqual(result.exit_code, 0)
-        self.assertIn("close", responses.calls[0].request.url, "No record request")
+        self.assertIn(
+            "close", responses.calls[1].request.url, "No record request")
